@@ -31,49 +31,49 @@ class WpaCli:
     Wraps the wpa_cli command line interface.
     """
 
-    def __init__(self, logger='picast'):
+    def __init__(self, logger="picast"):
         self.logger = getLogger(logger)
         pass
 
     def cmd(self, *argv):
         p = subprocess.Popen(["sudo", "wpa_cli"] + list(argv), stdout=subprocess.PIPE)
         stdout = p.communicate()[0]
-        return stdout.decode('UTF-8').splitlines()
+        return stdout.decode("UTF-8").splitlines()
 
     def start_p2p_find(self):
         self.logger.debug("wpa_cli p2p_find type=progressive")
         status = self.cmd("p2p_find", "type=progressive")
-        if 'OK' not in status:
+        if "OK" not in status:
             raise WpaException("Fail to start p2p find.")
 
     def stop_p2p_find(self):
         self.logger.debug("wpa_cli p2p_stop_find")
         status = self.cmd("p2p_stop_find")
-        if 'OK' not in status:
+        if "OK" not in status:
             raise WpaException("Fail to stop p2p find.")
 
     def set_device_name(self, name: str):
         self.logger.debug("wpa_cli set device_name {}".format(name))
         status = self.cmd("set", "device_name", name)
-        if 'OK' not in status:
+        if "OK" not in status:
             raise WpaException("Fail to set device name {}".format(name))
 
     def set_device_type(self, type):
         self.logger.debug("wpa_cli set device_type {}".format(type))
         status = self.cmd("set", "device_type", type)
-        if 'OK' not in status:
+        if "OK" not in status:
             raise WpaException("Fail to set device type {}".format(type))
 
     def set_p2p_go_ht40(self):
         self.logger.debug("wpa_cli set p2p_go_ht40 1")
         status = self.cmd("set", "p2p_go_ht40", "1")
-        if 'OK' not in status:
+        if "OK" not in status:
             raise WpaException("Fail to set p2p_go_ht40")
 
     def wfd_subelem_set(self, key: int, val: str):
         self.logger.debug("wpa_cli wfd_subelem_set {0:d} {1:s}".format(key, val))
         status = self.cmd("wfd_subelem_set", "{0:d}".format(key), val)
-        if 'OK' not in status:
+        if "OK" not in status:
             raise WpaException("Fail to wfd_subelem_set.")
 
     def p2p_group_add(self, name: str):
@@ -113,7 +113,7 @@ class WpaCli:
     def get_p2p_interface(self) -> Optional[str]:
         sel, interfaces = self.get_interfaces()
         for it in interfaces:
-            if it.startswith("p2p-"):
+            if it.startswith("p2p-") and not it.startswith("p2p-dev"):
                 return it
         return None
 
